==> haskell-warp-quic-0.0.0-423-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-FlTcRcGDkoM5IjpaNTcwEU
key:                  warp-quic-0.0.0-FlTcRcGDkoM5IjpaNTcwEU
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  125c9b8e1bfb8beabfc228e45363b71f
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-quic-0.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-FlTcRcGDkoM5IjpaNTcwEU
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http3-0.0.9-E9vd6MflxB6K6lBl861e7w
    quic-0.1.26-H0HytmFNAweFkRR9zmzsb4 tls-2.0.6-HHKVvNcSfLyJGme2UrIiax
    wai-3.2.4-DrO6v22Rmno6pXUhKStSuj warp-3.4.0-HpC7vpiyF2eriPYOziTRJ

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-quic-0.0.0-425-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-GPYVCLwDNaD1BDqOoq9wR4
key:                  warp-quic-0.0.0-GPYVCLwDNaD1BDqOoq9wR4
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  a99ca9b6758488869ec519a151c96fb5
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-quic-0.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-GPYVCLwDNaD1BDqOoq9wR4
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http3-0.0.9-96L95RDzn3uKoQz6BLYpdu
    quic-0.1.26-7WHAlB5OPHxDDWxQdvVEEO tls-2.0.6-CMnie4Wyps5DmePV9nSMbU
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63 warp-3.4.0-EMEx6bSExsO4TCzNcPaO2H

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
